#!/bin/sh -e
# ==============================================================================
# portsreinstall library script
# Overlay onto lib/libmain.sh for portsreinstall-chroot
# - Common functions of main programs -
# Copyright (C) 2018 Mamoru Sakaue, MwGhennndo, All Rights Reserved.
# This software is distributed under the 2-Clause BSD License.
# ==============================================================================

# ============= Set termination messages which should be shown after mounting file systems =============
main_inspect_fs_privilege ()
{
	misc_chk_privilege || return 0
	fs_inspect_fs_privilege
	message_echo
	temp_terminate_process ()
	{
		local errno
		errno=${1:-0}
		fs_chk_unmount > /dev/null || ( fs_unmount ) || :
		temp_terminate_process_common "$errno"
	}
	[ $TEMP_IN_TRAP = no ] || temp_terminate_process
}
